==> haskell-mod-0.2.0.1-48-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-mod.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 mod
version:              0.2.0.1
visibility:           public
id:                   mod-0.2.0.1-KusLUStg98aHzR0I3vU4Uq
key:                  mod-0.2.0.1-KusLUStg98aHzR0I3vU4Uq
license:              MIT
copyright:            2017-2022 Andrew Lelechenko
maintainer:           Andrew Lelechenko <andrew.lelechenko@gmail.com>
author:               Andrew Lelechenko <andrew.lelechenko@gmail.com>
homepage:             https://github.com/Bodigrim/mod
synopsis:             Fast type-safe modular arithmetic
description:
    <https://en.wikipedia.org/wiki/Modular_arithmetic Modular arithmetic>,
    promoting moduli to the type level, with an emphasis on performance.
    Originally part of the <https://hackage.haskell.org/package/arithmoi arithmoi> package.

category:             Math, Number Theory
abi:                  c47040fa66d93e74a0a536edd38606cb
exposed:              True
exposed-modules:      Data.Mod Data.Mod.Word
hidden-modules:       Data.Mod.Compat
import-dirs:          /usr/lib/ghc-9.2.8/site-local/mod-0.2.0.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/mod-0.2.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mod
hs-libraries:         HSmod-0.2.0.1-KusLUStg98aHzR0I3vU4Uq
depends:
    base-4.16.4.0 deepseq-1.4.6.1 ghc-bignum-1.2
    primitive-0.7.4.0-A9DQl7IN10ADdryf8HN1sF
    semirings-0.6-HrLFL9KATFkDlEaoQRKJLH
    vector-0.13.1.0-FqETZo7rR6n5zX4PwJIjNh

haddock-interfaces:   /usr/share/doc/haskell-mod/html/mod.haddock
haddock-html:         /usr/share/doc/haskell-mod/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mod-0.2.0.1-57-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-mod.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 mod
version:              0.2.0.1
visibility:           public
id:                   mod-0.2.0.1-AQHRY81UY789XuHU2wjU3u
key:                  mod-0.2.0.1-AQHRY81UY789XuHU2wjU3u
license:              MIT
copyright:            2017-2022 Andrew Lelechenko
maintainer:           Andrew Lelechenko <andrew.lelechenko@gmail.com>
author:               Andrew Lelechenko <andrew.lelechenko@gmail.com>
homepage:             https://github.com/Bodigrim/mod
synopsis:             Fast type-safe modular arithmetic
description:
    <https://en.wikipedia.org/wiki/Modular_arithmetic Modular arithmetic>,
    promoting moduli to the type level, with an emphasis on performance.
    Originally part of the <https://hackage.haskell.org/package/arithmoi arithmoi> package.

category:             Math, Number Theory
abi:                  8f78dfa3c1c956d8e7e9d747f141bdad
exposed:              True
exposed-modules:      Data.Mod Data.Mod.Word
hidden-modules:       Data.Mod.Compat
import-dirs:          /usr/lib/ghc-9.2.8/site-local/mod-0.2.0.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/mod-0.2.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mod
hs-libraries:         HSmod-0.2.0.1-AQHRY81UY789XuHU2wjU3u
depends:
    base-4.16.4.0 deepseq-1.4.6.1 ghc-bignum-1.2
    primitive-0.7.4.0-AQ7cOoBXu5aBgAQTQzTLUx
    semirings-0.6-1Mmgwd2bHEZ2ZWjOvPwut1
    vector-0.13.1.0-xP3uH1g3cPFld8g0jCD5r

haddock-interfaces:   /usr/share/doc/haskell-mod/html/mod.haddock
haddock-html:         /usr/share/doc/haskell-mod/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
